use image::{DynamicImage, GenericImageView};

use crate::config::image_processors::ProcessorParams;
use crate::result::{MBGResult};

use super::ImageProcessor;

pub struct CropProcessor {
    pub params: ProcessorParams,
    pub screen_height: i32,
    pub screen_width: i32,
    pub height: u32,
    pub width: u32,
    pub fit: bool,
}

impl ImageProcessor for CropProcessor {
    fn process(&self, img: &DynamicImage) -> MBGResult<DynamicImage> {
        let mut res = img.clone();
        let mut requested_width = self.width;
        let mut requested_height = self.height;
        if self.fit {
            debug!("Cropping image to match screen size");
            requested_width = self.screen_width as u32;
            requested_height = self.screen_height as u32;
        }
        debug!("Cropping image to be {}x{}", requested_width, requested_height);
        let start_x = (res.width() / 2) - (requested_width / 2);
        let start_y = (res.height() / 2) - (requested_height / 2);
        Ok(res.crop(start_x, start_y, requested_width, requested_height))
    }
}